# react-native-dropdown-with-search-and-checkbox

A customizable React Native dropdown component featuring:

- 🔍 Search functionality
- ☑️ Checkbox selection (single & multiple)
- 🛠️ Fully styleable props
- 📱 Smooth modal-based dropdown experience

---

## 🚀 Installation

```bash
npm install react-native-dropdown-with-search-and-checkbox


Also install the required dependencies:
npm install react-native-elements react-native-vector-icons

If you're not using autolinking (React Native <= 0.59), link vector icons manually:
npx react-native link react-native-vector-icons


📦 Usage

import React, { useState } from 'react';
import { View } from 'react-native';
import { DropdownSearch } from 'react-native-dropdown-with-search-and-checkbox';

const App = () => {
  const [selectedItems, setSelectedItems] = useState([]);

  const data = [
    { label: 'Apple', value: 'apple' },
    { label: 'Banana', value: 'banana' },
    { label: 'Mango', value: 'mango' },
  ];

  return (
    <View style={{ flex: 1, justifyContent: 'center' }}>
      <DropdownSearch
        label="Fruits"
        data={data}
        placeholder="Select fruits"
        multiSelect={true}
        showCheckbox="multiple"
        showFilter={true}
        onSelect={items => setSelectedItems(items)}
      />
    </View>
  );
};

export default App;



⚙️ Props

| Prop                | Type      | Default       | Description |
|---------------------|-----------|---------------|-------------|
| `data`              | `array`   | `[]`          | List of items to display |
| `onSelect`          | `func`    | required      | Callback when selection is made |
| `label`             | `string`  | `''`          | Label shown above the dropdown |
| `placeholder`       | `string`  | `'Select...'` | Placeholder when nothing is selected |
| `labelKey`          | `string`  | `'label'`     | Key name to use for labels in your data |
| `valueKey`          | `string`  | `'value'`     | Key name to use for values in your data |
| `multiSelect`       | `bool`    | `false`       | Enable multiple selection |
| `showCheckbox`      | `string`  | `null`        | `'multiple'` to show checkboxes |
| `showFilter`        | `bool`    | `false`       | Show a filter icon and optional filter input |
| `saveButtonText`    | `string`  | `'Save'`      | Text for the Save button (multi-select) |
| `placeholderStyle`  | `object`  | `{}`          | Custom style for placeholder text |
| `downArrowStyle`    | `object`  | `{}`          | Style for down arrow icon |
| `filterIconStyle`   | `object`  | `{}`          | Style for filter icon |
| `searchInputStyle`  | `object`  | `{}`          | Style for search input field |
| `dropdownButtonstyle` | `object` | `{}`         | Style for dropdown button container |
| `checkboxstyle`     | `object`  | `{}`          | Style for checkbox |
| `checkboxcolor`     | `string`  | `'#007bff'`   | Color of the checkbox tick |


📄 License

MIT


👤 Author
Bhumit Dara

GitHub: @bhumitdara

NPM: @bhumitdara


---

